export declare class Scrollbars {
    /**
     * The scrollbar DOM element.
     *
     * @type {DOM}
     */
    elements: any;
    /**
     * Selector on elements to apply to.
     *
     * @type {string}
     */
    selector: string;
    /**
     * Create a new instance.
     *
     * @param  {string} selector
     */
    constructor(selector?: string);
    /**
     * Initalizer.
     *
     * @return {void}
     */
    init(): void;
    /**
     * Create new scrollbar elements.
     *
     * @param  {HTMLElement} element
     * @return {void}
     */
    create(element: HTMLElement): void;
    /**
     * Destory the scrollbar attributes.
     *
     * @param  {HTMLElement} element
     * @return {void}
     */
    destroy(element: HTMLElement): void;
    /**
     * Observe the dom for new scrollbar elements.
     *
     * @return {void}
     */
    observe(): void;
    /**
     * Resize the scrollbars on window resize event.
     *
     * @return {void}
     */
    resize(): void;
    /**
     * Add class to the parent elemeent.
     *
     * @param  {HTMLElement} element
     * @return {void}
     */
    parentClass(element: HTMLElement): void;
    /**
     * Determine the height of the scrollbar.
     *
     * @param  {HTMLElement} element
     * @return {void}
     */
    position(element: HTMLElement): void;
    /**
     * Adjust the scroll bar height.
     *
     * @param {HTMLElement} element
     * @return {void}
     */
    height(element: HTMLElement): void;
    /**
     * Determin if the scroll should be visible.
     *
     * @param {HTMLElement} element
     * @return {void}
     */
    visible(element: HTMLElement): void;
    /**
     * Set the right margin of the scrolling element.
     *
     * @param {HTMLElement} element
     * @return {void}
     */
    margin(element: HTMLElement): void;
    /**
     * On scroll event handler.
     *
     * @param {HTMLElement} element
     * @return {void}
     */
    onScroll(element: HTMLElement): void;
    /**
     * On click event handler.
     *
     * @param  {HTMLElement} element
     * @return {void}
     */
    onClick(element: HTMLElement): void;
    onDrag(element: HTMLElement): void;
}
