"use strict";
var Scrollbars = (function () {
    /**
     * Create a new instance.
     *
     * @param  {string} selector
     */
    function Scrollbars(selector) {
        if (selector === void 0) { selector = ''; }
        /**
         * Selector on elements to apply to.
         *
         * @type {string}
         */
        this.selector = '';
        this.selector = selector;
        this.init();
        this.observe();
    }
    /**
     * Initalizer.
     *
     * @return {void}
     */
    Scrollbars.prototype.init = function () {
        var _this = this;
        if (this.selector) {
            this.elements = document.querySelectorAll(this.selector);
            this.elements.forEach(function (element) { return _this.create(element); });
        }
        this.resize();
    };
    /**
     * Create new scrollbar elements.
     *
     * @param  {HTMLElement} element
     * @return {void}
     */
    Scrollbars.prototype.create = function (element) {
        this.parentClass(element);
        this.height(element);
        this.visible(element);
        this.onScroll(element);
        this.onClick(element);
    };
    /**
     * Destory the scrollbar attributes.
     *
     * @param  {HTMLElement} element
     * @return {void}
     */
    Scrollbars.prototype.destroy = function (element) {
        element.parentElement.classList.remove('scrollbars-container');
        element.classList.remove('scrollbar-hidden');
        element.removeEventListener('scroll');
        element.removeEventListener('click');
        //element.removeEventListener('drag');
        delete element.dataset['scroll'];
    };
    /**
     * Observe the dom for new scrollbar elements.
     *
     * @return {void}
     */
    Scrollbars.prototype.observe = function () {
        var target = document.body;
        var observer = new MutationObserver(function (mutations) {
            mutations.forEach(function (mutation) {
                if (mutation.type == 'childList') {
                }
            });
        });
        observer.observe(target, {
            attributes: true,
            childList: true,
            characterData: true
        });
    };
    /**
     * Resize the scrollbars on window resize event.
     *
     * @return {void}
     */
    Scrollbars.prototype.resize = function () {
        var _this = this;
        window.addEventListener('resize', function () {
            _this.elements.forEach(function (element) { return _this.height(element); });
        });
    };
    /**
     * Add class to the parent elemeent.
     *
     * @param  {HTMLElement} element
     * @return {void}
     */
    Scrollbars.prototype.parentClass = function (element) {
        element.parentElement.classList.add('scrollbars-container');
    };
    /**
     * Determine the height of the scrollbar.
     *
     * @param  {HTMLElement} element
     * @return {void}
     */
    Scrollbars.prototype.position = function (element) {
        var ratio = (element.scrollTop / element.scrollHeight);
        var data_scroll = Math.round(ratio * 1000);
        element.dataset['scroll'] = data_scroll.toString();
    };
    /**
     * Adjust the scroll bar height.
     *
     * @param {HTMLElement} element
     * @return {void}
     */
    Scrollbars.prototype.height = function (element) {
        if (element) {
            var ratio = element.clientHeight / element.scrollHeight;
            var height = ratio * 100;
            var data_height = Math.floor(height);
            element.dataset['scrollBar'] = data_height.toString();
        }
    };
    /**
     * Determin if the scroll should be visible.
     *
     * @param {HTMLElement} element
     * @return {void}
     */
    Scrollbars.prototype.visible = function (element) {
        if (element.scrollHeight > element.clientHeight) {
            element.classList.remove('scrollbar-hidden');
        }
        else {
            element.classList.add('scrollbar-hidden');
        }
    };
    /**
     * Set the right margin of the scrolling element.
     *
     * @param {HTMLElement} element
     * @return {void}
     */
    Scrollbars.prototype.margin = function (element) {
        element.style.marginRight = '-15px';
    };
    /**
     * On scroll event handler.
     *
     * @param {HTMLElement} element
     * @return {void}
     */
    Scrollbars.prototype.onScroll = function (element) {
        var _this = this;
        element.addEventListener('scroll', function (event) {
            _this.position(event.target);
            _this.height(event.target);
        });
    };
    /**
     * On click event handler.
     *
     * @param  {HTMLElement} element
     * @return {void}
     */
    Scrollbars.prototype.onClick = function (element) {
        element.addEventListener('click', function (e) {
            if (e.target !== element)
                return;
            if (e.target['offsetWidth'] - e.x < 30) {
                var click_percentage = Math.round((e.clientY / element.clientHeight) * 100);
                var scroll_top = (element.scrollHeight * click_percentage) / 100;
                element.scrollTop = scroll_top;
            }
        });
    };
    Scrollbars.prototype.onDrag = function (element) {
        element.addEventListener('click', function (e) {
            if (e.target !== element)
                return;
            if (e.target['offsetWidth'] - e.x < 30) {
            }
        });
    };
    return Scrollbars;
}());
exports.Scrollbars = Scrollbars;
